@@ -1,8 +1,20 @@
 
 Sys.setenv(LANG = "en")
 
+
 options(stringsAsFactors = FALSE)
+options(testthat.progress.max_fails = 50)
 options(width = 200)
+
+options(crosstable_verbosity_autotesting="quiet")
+options(lifecycle_verbosity="warning")
+# if(testthat::is_testing()){
+# print(is_parallel())
+if(FALSE){
+    v=View
+    # prettycode::prettycode()
+}
+
 # options(warn = 2)
 # options(warn = 1)
 # options(tidyselect_verbosity = "verbose") #quiet or verbose
@@ -23,6 +35,7 @@ mtcars3$cyl3 = mtcars3$cyl==3
 mtcars3$cyl6 = mtcars3$cyl==6
 mtcars3$dummy = "dummy"
 mtcars3$dummy_na = NA
+mtcars3$dummy_na2 = NA
 mtcars3$dummy_num_vs = ifelse(mtcars3$vs=="vshaped", 0, rnorm(15))
 mtcars3$dummy2 = mtcars3$dummy
 mtcars3$dummy2[5:12] = NA
@@ -34,13 +47,33 @@ mtcars3$diff = difftime(mtcars3$hp_date, mtcars3$qsec_posix, units="days") %>% s
 
 
 
-
 # Functions ---------------------------------------------------------------
 iris2names = c(SL="Sepal.Length", SW="Sepal.Width", PL="Petal.Length", PW="Petal.Width", Sp="Species")
 iris2_num = iris2 %>% select(-Species)
 
 
-expect_cross = function(expr, xnames, byname, dim, expect=c("nothing", "silent", "warning", "error"), regex){
+expect_cross = function(x, xnames, byname, dim, regex){
+    # expect=match.arg(expect)
+    # if(expect=="nothing"){
+    #     x=eval(expr, envir=caller_env())
+    # }
+    # else if(expect=="silent")
+    #     x=expect_silent(expr)
+    # else if(expect=="warning")
+    #     x=expect_warning(expr, regex)
+    # else
+    #     x=expect_error(expr, regex)
+    expect_s3_class(x, c("data.frame", "crosstable"))
+    expect_equal(dim, dim(x))
+    expect_equal(byname, unname(attr(x, "by")))
+    
+    if(all(xnames %in% names(iris2names)))
+        expect_equal(unname(iris2names[xnames]), unique(as.character(x$.id)))
+    else
+        expect_equal(unname(xnames), unique(x$.id))
+}
+
+expect_cross_bak = function(expr, xnames, byname, dim, expect=c("nothing", "silent", "warning", "error"), regex){
     expect=match.arg(expect)
     if(expect=="nothing"){
         x=eval(expr, envir=caller_env())
@@ -64,5 +97,14 @@ expect_cross = function(expr, xnames, byname, dim, expect=c("nothing", "silent",
 
 
 
+expect_warning2 = function(object, ...) {
+    rtn = testthat::expect_warning(object, ...)
+    if (inherits(object, "condition")) {
+        attr(rtn, "object") = attr(object, "object")
+    } else{
+        attr(rtn, "object") = object
+    }
+    rtn
+}
 
 print('Helper loaded')
\ No newline at end of file
